@@ -2,8 +2,8 @@ import json
 import operator
 import sys
 
-from json_models.flight_json_model import FlightJsonModel
-from json_models.plan_json_model import PlanJsonModel
+from flight_routes.json_models.flight_json_model import FlightJsonModel
+from flight_routes.json_models.plan_json_model import PlanJsonModel
 
 
 def to_json(list_of_flights, indexed_flights, origin, destination, bags):
